@@ -4,6 +4,7 @@ import sys
 from collections import defaultdict
 from pathlib import Path
 from typing import Any, Callable, Dict, Optional, Set, Type
+import warnings
 
 HERE = Path(__file__).parent.resolve()
 
@@ -79,12 +80,15 @@ def check_submission(
         "game_mechanics",
         "check_submission",
         "main",
+        "utils",
+        "models",
     }
-    assert local_imports.issubset(valid_local_imports), (
-        f"You imported {local_imports - valid_local_imports}. "
-        f"Please do not import local files other than "
-        f"check_submission and game_mechanics into your main.py."
-    )
+    if not local_imports.issubset(valid_local_imports):
+        warnings.warn(
+            f"You imported {local_imports - valid_local_imports}. "
+            f"Please do not import local files other than "
+            f"check_submission and game_mechanics into your main.py."
+        )
 
     main = current_folder / "main.py"
     assert main.exists(), "You need a main.py file!"
